@@ -1,4 +1,4 @@
-/* $Id: dialogs.c 28003 2008-10-01 07:57:03Z kelnos $ */
+/* $Id: dialogs.c 28378 2008-10-23 08:10:03Z stephan $ */
 /*
  * Copyright (c) 2003,2005 Jasper Huijsmans <jasper@xfce.org>
  * Copyright (c) 2003 Benedikt Meurer <benny@xfce.org>
@@ -275,7 +275,7 @@ message_dialog (GtkMessageType type, const gchar * message)
 
     dlg = gtk_message_dialog_new (NULL,
 				  GTK_DIALOG_MODAL,
-				  type, GTK_BUTTONS_CLOSE, message);
+				  type, GTK_BUTTONS_CLOSE, "%s", message);
 
     xfce_gtk_window_center_on_monitor_with_pointer (GTK_WINDOW (dlg));
     gtk_dialog_run (GTK_DIALOG (dlg));
@@ -444,7 +444,7 @@ xfce_confirm (const gchar *text,
     dialog = gtk_message_dialog_new (NULL,
                                      GTK_DIALOG_MODAL,
                                      GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE,
-                                     text);
+                                     "%s", text);
     if (strcmp (stock_id, GTK_STOCK_YES) == 0)
         button = gtk_button_new_from_stock (GTK_STOCK_NO);
     else
