@@ -480,6 +480,21 @@ netk_screen_get_active_window (NetkScreen * screen)
     return screen->priv->active_window;
 }
 
+/**
+ * netk_screen_get_workspaces:
+ * @screen: a #NetkScreen
+ * 
+ * Gets the screen's list of workspaces. 
+ * The list is not copied and should not be freed. 
+ *
+ * Return value: reference to list of workspaces
+ **/
+GList*
+netk_screen_get_workspaces (NetkScreen * screen)
+{
+    return screen->priv->workspaces;
+}
+
 /**
  * netk_screen_get_windows:
  * @screen: a #NetkScreen
