@@ -2177,6 +2177,40 @@ p_netk_set_icon_geometry (Window xwindow, int x, int y, int width, int height)
     p_netk_error_trap_pop ();
 }
 
+gboolean
+p_netk_get_icon_geometry (Window xwindow, int* x, int* y, int* width, int* height)
+{
+    Atom type;
+    int format;
+    gulong nitems;
+    gulong bytes_after;
+    gulong *data;
+    int err, result;
+
+    p_netk_error_trap_push ();
+    type = None;
+    result = XGetWindowProperty (gdk_display, xwindow, p_netk_atom_get ("_NET_WM_ICON_GEOMETRY"), 0, 4, False, XA_CARDINAL, &type, &format, &nitems, &bytes_after, (guchar **)&data);
+    err = p_netk_error_trap_pop ();
+    
+    if (err != Success || result != Success)
+        return FALSE;
+
+    if (type != XA_CARDINAL || nitems != 4)
+    {
+        XFree (data);
+        return FALSE;
+    }
+
+    *x = (int) data[0];
+    *y = (int) data[1];
+    *width = (int) data[2];
+    *height = (int) data[3];
+
+    XFree (data);
+
+    return TRUE;
+}
+
 void
 p_netk_set_type_hint (Window xwindow, NetkWindowType type)
 {
